@@ -2,6 +2,8 @@ package Test::BrewBuild::BrewCommands;
 use strict;
 use warnings;
 
+our $VERSION = '1.03_03';
+
 my $log;
 
 sub new {
@@ -11,27 +13,42 @@ sub new {
 
     $self->{log} = $plog->child('Test::BrewBuild::BrewCommands');
     $log = $self->{log};
-    $log->_7("constructing new Test::BrewBuild::BrewCommands object");
+    $log->_6("constructing new Test::BrewBuild::BrewCommands object");
 
     return $self;
 }
 sub brew {
     my $self = shift;
     my $brew = $self->is_win ? 'berrybrew' : 'perlbrew';
-    $log->child('brew')->_7("*brew cmd is: $brew");
+    $log->child('brew')->_6("*brew cmd is: $brew");
     return $brew;
 }
 sub installed {
     my ($self, $info) = @_;
 
-    $log->child('installed')->_7("cleaning up perls installed");
+    $log->child('installed')->_6("cleaning up perls installed");
 
     return if ! $info;
 
     return $self->is_win
         ? $info =~ /(\d\.\d{2}\.\d(?:_\d{2}))(?!=_)\s+\[installed\]/ig
         : $info =~ /i.*?(perl-\d\.\d+\.\d+)/g;
+}
+sub using {
+    my ($self, $info) = @_;
 
+    $log->child( 'using' )->_6( "checking for which ver we're using" );
+
+    if ($self->is_win) {
+        my @installed = $info =~ /(\d\.\d{2}\.\d(?:_\d{2}))(?!=_)\s+\[installed\]\*/ig;
+        return $installed[0];
+    }
+    else {
+        my $using = $^V;
+        $using =~ s/v//;
+        $using = "perl-$using";
+        return $using;
+    }
 }
 sub available {
     my ($self, $info) = @_;
@@ -39,26 +56,21 @@ sub available {
 
     if ($info){
 
-        $log->child('available')->_7("determining available perls");
+        $log->child('available')->_6("determining available perls");
 
         my @avail = $self->is_win
             ? $info =~ /(\d\.\d+\.\d+_\d+)/g
             : $info =~ /(perl-\d\.\d+\.\d+)/g;
 
-        if ($self->is_win) {
-            for (@avail) {
-                s/perl-//;
-            }
-        }
         return @avail;
     }
     else {
 
-        $log->child('available')->_7("generating available");
+        $log->child('available')->_6("generating available");
 
         return $self->is_win
-            ? `berrybrew available`
-            : `perlbrew available`;
+            ? `berrybrew available 2>nul`
+            : `perlbrew available 2>/dev/null`;
     }
 }
 sub install {
@@ -68,7 +80,7 @@ sub install {
         ? 'berrybrew install'
         : 'perlbrew install --notest -j 4';
 
-    $log->child('install')->_7("install cmd is: $install_cmd");
+    $log->child('install')->_6("install cmd is: $install_cmd");
 
     return $install_cmd;
 }
@@ -79,19 +91,10 @@ sub remove {
         ? 'berrybrew remove'
         : 'perlbrew uninstall';
 
-    $log->child('remove')->_7("remove cmd is: $remove_cmd");
+    $log->child('remove')->_6("remove cmd is: $remove_cmd");
 
     return $remove_cmd;
 }
-sub version {
-    my ($self, $ver) = shift;
-
-    $log->child('version')->_7("configuring version");
-
-    return $self->is_win
-        ? $ver
-        : "perl-$ver";
-}
 sub is_win {
     my $is_win = ($^O =~ /Win/) ? 1 : 0;
     return $is_win;
@@ -123,6 +126,10 @@ installed versions, formatted in a platform specific manner.
 
 Similar to C<installed()>, but returns all perls available.
 
+=head2 using($info)
+
+Returns the current version of perl we're using.
+
 =head2 install
 
 Returns the current OS's specific *brew install command.
@@ -131,10 +138,6 @@ Returns the current OS's specific *brew install command.
 
 Returns the current OS's specific *brew remove command.
 
-=head2 version
-
-Returns the platform specific perl version string.
-
 =head2 is_win
 
 Returns 0 if on Unix, and 1 if on Windows.
